==> MATT-Bundle-0.6.0.tar.gz: MATT-Bundle-0.6.0/Apache.pm <==
#!/usr/bin/perl
use strict;

package MATT::Apache;

use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

$VERSION  = '0.1.0';

use Exporter;
use MATT::Utility;
use MATT::FreeBSD;

@ISA = qw(Exporter);
@EXPORT = qw(
	InstallApache1
	InstallApache2
);
@EXPORT_OK = qw( RemoveOldApacheSources );



sub InstallApache2
{
	print "\n";
	InstallPackage("p5-libwww");
	InstallPackage("apache2", "apache-2");
	InstallPort   ("perl5",       "lang", "", "perl-5");
	SysCmd("/usr/local/bin/use.perl port");
	InstallPort   ("cronolog", "sysutils");
	InstallPort   ("mod_php4", "www");
	InstallPort   ("mod_perl2", "www");
};

sub InstallApache1($;$) 
{
	my ($src) = @_;

	my $apache   = "apache_1.3.27";
	my $mod_perl = "mod_perl-1.27";
	my $mod_ssl  = "mod_ssl-2.8.14-1.3.27";
	my $layout   = "FreeBSD.layout";

	InstallPackage("mm");
	InstallPackage("gettext");
	InstallPackage("libtool");
	InstallPackage("apache");
	InstallPackage("p5-libwww");
	InstallPort   ("cronolog", "sysutils");

	my $log = "/var/log/apache";
	if (! -d $log) 
	{
		mkdir($log, 0755) or die "Couldn't create $log: $!\n";
		my $uid = getpwnam("www");
		my $gid = getgrnam("www");
		chown($uid, $gid, $log);
	};

	CdSrcDir("$src/www");

	if ( !-e "$apache.tar.gz" ) {
		FetchFile("http://www.apache.org/dist/httpd/$apache.tar.gz");
	};

	if ( !-e "$mod_perl.tar.gz" ) {
		FetchFile("http://perl.apache.org/dist/$mod_perl.tar.gz");
	};

	if ( !-e "$mod_ssl.tar.gz" ) {
		FetchFile("http://www.modssl.org/source/$mod_ssl.tar.gz");
	};

	if ( !-e $layout ) 
	{
		FetchFile("http://matt.simerson.net/computing/www/apache.layout");
		move("apache.layout", $layout);
	};

	RemoveOldApacheSources($apache);

	foreach my $package ( $apache, $mod_perl, $mod_ssl) 
	{
		if ( -d $package )
		{
			my $r = SourceWarning($package, 1);
			if (! $r) { die "sorry, I can't continue.\n"; };
		};
		my $tar = FindTheBin("tar");
		SysCmd("$tar -xzf $package.tar.gz");
	};

	chdir($mod_ssl);
	SysCmd("./configure --with-apache=../$apache --with-ssl=/usr --enable-shared=ssl --with-mm=/usr/local");
	chdir("../$mod_perl");
	SysCmd( "perl Makefile.PL DO_HTTPD=1 USE_APACI=1 APACHE_PREFIX=/usr/local EVERYTHING=1 APACI_ARGS='--server-uid=www, --server-gid=www, --enable-module=so --enable-module=most, --enable-shared=max --disable-shared=perl, --enable-module=perl, --with-layout=../$layout:FreeBSD, --without-confadjust'");
	SysCmd("make");

	if (-e "../$apache/src/httpd") 
	{
		print <<EOM

Apache build successful, now you must install as follows:

For new installs:

     cd $src/www/$mod_perl
     make test
     cd ../$apache; make certificate TYPE=custom
     rm /usr/local/etc/apache/httpd.conf
     cd ../$mod_perl; make install
     cd /usr/ports/www/mod_php4; make install clean (optional)
     apachectl stop; apachectl startssl

For re-installs:

     cd $src/www/$mod_perl;\n\tmake test
     make install
     cd /usr/ports/www/mod_php4; make install clean (optional)
     apachectl stop; apachectl startssl
EOM
;
	};
};

sub RemoveOldApacheSources
{
	my ($apache) = @_;

	my @list = <apache_1.*>;
	foreach my $dir (@list)
	{
		if ( $dir ne $apache && $dir !~ /\.tar\.gz$/ )
		{
			print "deleting: $dir... ";
			rmtree $_ or die "couldn't delete $_: $!\n";    
			print "done.";
		};       
	};
};

1;
__END__

==> MATT-Bundle-0.7.0.tar.gz: MATT-Bundle-0.7.0/Apache.pm <==
#!/usr/bin/perl
use strict;

package MATT::Apache;

use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);

$VERSION  = '0.3.0';

=head1 NAME

	MATT::Apache - Install Apache 1 or 2 on FreeBSD

=head1 SYNOPSIS

	Builds a high performance statically compiled web server with
	SSL, PHP, and Perl support.

=head1 DESCRIPTION

	Builds Apache from sources with DSO for all but mod_perl which
	must be compiled statically in order to work at all with 
	Apache 1.x. Apache 2 is much nicer and can be installed with
	mod_perl2 as a DSO and still run without crashing.

	Also installs mod_perl, mod_php4, and mod_ssl.

=cut

use Exporter;
use MATT::Utility;
use MATT::FreeBSD;

@ISA = qw(Exporter);
@EXPORT = qw(
	InstallApache1
	InstallApache2
);
@EXPORT_OK = qw( RemoveOldApacheSources CdSrcDir );


sub InstallApache2
{

=head2 InstallApache2

	use MATT::Apache;
	InstallApache2();

	will build Apache. Currently only works on FreeBSD.

=cut
	print "\n";
	InstallPackage("p5-libwww");
	InstallPackage("apache2", "apache-2");
	InstallPort   ("perl5",       "lang", "", "perl-5");
	SysCmd("/usr/local/bin/use.perl port");
	InstallPort   ("cronolog", "sysutils");
	InstallPort   ("mod_php4", "www");
	InstallPort   ("mod_perl2", "www");
};

sub InstallApache1($;$) 
{
	my ($src) = @_;

=head2 InstallApache1

	use MATT::Apache;
	InstallApache1("/usr/local/src")

	will build Apache in the directory as shown. When it's done
	the script will show you a few options for testing and
	completing the installation.

=cut

	use File::Copy;

	my $apache   = "apache_1.3.27";
	my $mod_perl = "mod_perl-1.27";
	my $mod_ssl  = "mod_ssl-2.8.14-1.3.27";
	my $layout   = "FreeBSD.layout";

	InstallPackage("mm");
	InstallPackage("gettext");
	InstallPackage("libtool");
	InstallPackage("apache");
	InstallPackage("p5-libwww");
	InstallPort   ("cronolog", "sysutils");

	my $log = "/var/log/apache";
	if (! -d $log) 
	{
		mkdir($log, 0755) or die "Couldn't create $log: $!\n";
		my $uid = getpwnam("www");
		my $gid = getgrnam("www");
		chown($uid, $gid, $log);
	};

	CdSrcDir("$src/www", $src);

	if ( !-e "$apache.tar.gz" ) {
		FetchFile("http://www.apache.org/dist/httpd/$apache.tar.gz");
	};

	if ( !-e "$mod_perl.tar.gz" ) {
		FetchFile("http://perl.apache.org/dist/$mod_perl.tar.gz");
	};

	if ( !-e "$mod_ssl.tar.gz" ) {
		FetchFile("http://www.modssl.org/source/$mod_ssl.tar.gz");
	};

	if ( !-e $layout ) 
	{
		FetchFile("http://matt.simerson.net/computing/www/apache.layout");
		move("apache.layout", $layout);
	};

	RemoveOldApacheSources($apache);

	foreach my $package ( $apache, $mod_perl, $mod_ssl) 
	{
		if ( -d $package )
		{
			my $r = SourceWarning($package, 1);
			if (! $r) { die "sorry, I can't continue.\n"; };
		};
		my $tar = FindTheBin("tar");
		SysCmd("$tar -xzf $package.tar.gz");
	};

	chdir($mod_ssl);
	SysCmd("./configure --with-apache=../$apache --with-ssl=/usr --enable-shared=ssl --with-mm=/usr/local");
	chdir("../$mod_perl");
	SysCmd( "perl Makefile.PL DO_HTTPD=1 USE_APACI=1 APACHE_PREFIX=/usr/local EVERYTHING=1 APACI_ARGS='--server-uid=www, --server-gid=www, --enable-module=so --enable-module=most, --enable-shared=max --disable-shared=perl, --enable-module=perl, --with-layout=../$layout:FreeBSD, --without-confadjust'");
	SysCmd("make");

	if (-e "../$apache/src/httpd") 
	{
		print <<EOM

Apache build successful, now you must install as follows:

For new installs:

     cd $src/www/$mod_perl
     make test
     cd ../$apache; make certificate TYPE=custom
     rm /usr/local/etc/apache/httpd.conf
     cd ../$mod_perl; make install
     cd /usr/ports/www/mod_php4; make install clean (optional)
     apachectl stop; apachectl startssl

For re-installs:

     cd $src/www/$mod_perl;\n\tmake test
     make install
     cd /usr/ports/www/mod_php4; make install clean (optional)
     apachectl stop; apachectl startssl
EOM
;
	};
};

sub RemoveOldApacheSources
{
	my ($apache) = @_;

	my @list = <apache_1.*>;
	foreach my $dir (@list)
	{
		if ( $dir ne $apache && $dir !~ /\.tar\.gz$/ )
		{
			print "deleting: $dir... ";
			rmtree $_ or die "couldn't delete $_: $!\n";    
			print "done.";
		};       
	};
};

sub CdSrcDir($;$)
{
	my ($dir, $src) = @_;

	if ( !-e $src )
	{
		mkdir($src, 0755);
	} else {
		if (!-d $src)
		{
			die "Something (other than a directory) is at $src and that's my build directory. Please remove it and try again!\n";
		};
	};
   
	if ( !-e $dir )
	{
		mkdir($dir, 0755);
	};
   
	chdir($dir);
}; 


1;
__END__

=head2 Dependencies

	Matt::Bundle - http://matt.simerson.net/computing/perl/

=head1 AUTHOR

	Matt Simerson <matt@cadillac.net>

=head1 BUGS

	None known. Report any to author.

=head1 TODO

	Don't export any of the symbols by default. Move all symbols
	to EXPORT_OK and explicitely pull in the required ones in 
	programs that need them.

=head1 SEE ALSO

	http://matt.simerson.net/computing/www/

=head1 COPYRIGHT

	Copyright 2003, Matt Simerson. All Right Reserved.

=cut
